==> dotclear-2.10.4.zip: dotclear/locales/en/public.lang.php <==
<?php
# -- BEGIN LICENSE BLOCK ---------------------------------------
#
# This file is part of Dotclear 2.
#
# Copyright (c) 2003-2013 Olivier Meunier & Association Dotclear
# Licensed under the GPL version 2.0 license.
# See LICENSE file or
# http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
#
# -- END LICENSE BLOCK -----------------------------------------#
#
#
#		  DOT NOT MODIFY THIS FILE !




$GLOBALS['__l10n']['To content'] = '';
$GLOBALS['__l10n']['To menu'] = '';
$GLOBALS['__l10n']['To search'] = '';
$GLOBALS['__l10n']['By'] = '';
$GLOBALS['__l10n']['by'] = '';
$GLOBALS['__l10n']['on'] = '';
$GLOBALS['__l10n']['On'] = '';
$GLOBALS['__l10n']['Continue reading'] = '';
$GLOBALS['__l10n']['no comments'] = '';
$GLOBALS['__l10n']['one comment'] = '';
$GLOBALS['__l10n']['%d comments'] = '';
$GLOBALS['__l10n']['no trackbacks'] = '';
$GLOBALS['__l10n']['one trackback'] = '';
$GLOBALS['__l10n']['%d trackbacks'] = '';
$GLOBALS['__l10n']['no attachments'] = '';
$GLOBALS['__l10n']['one attachment'] = '';
$GLOBALS['__l10n']['%d attachments'] = '';
$GLOBALS['__l10n']['previous entries'] = '';
$GLOBALS['__l10n']['page'] = '';
$GLOBALS['__l10n']['of'] = '';
$GLOBALS['__l10n']['next entries'] = '';
$GLOBALS['__l10n']['Search'] = '';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned no result.'] = '';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned <strong>%2$s</strong> result.'] = '';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned <strong>%2$s</strong> results.'] = '';
$GLOBALS['__l10n']['Home'] = '';
$GLOBALS['__l10n']['All keywords'] = '';
$GLOBALS['__l10n']['Best of me'] = '';
$GLOBALS['__l10n']['Languages'] = '';
$GLOBALS['__l10n']['Categories'] = '';
$GLOBALS['__l10n']['Subcategories'] = '';
$GLOBALS['__l10n']['Archives'] = '';
$GLOBALS['__l10n']['Links'] = '';
$GLOBALS['__l10n']['Subscribe'] = '';
$GLOBALS['__l10n']['Entries feed'] = '';
$GLOBALS['__l10n']['Comments feed'] = '';
$GLOBALS['__l10n']['This blog\'s comments Atom feed'] = '';
$GLOBALS['__l10n']['This category\'s entries Atom feed'] = '';
$GLOBALS['__l10n']['This category\'s comments Atom feed'] = '';
$GLOBALS['__l10n']['This post\'s comments feed'] = '';
$GLOBALS['__l10n']['This post\'s comments Atom feed'] = '';
$GLOBALS['__l10n']['Attachments'] = '';
$GLOBALS['__l10n']['Permalink'] = '';
$GLOBALS['__l10n']['Comments'] = '';
$GLOBALS['__l10n']['Your comment'] = '';
$GLOBALS['__l10n']['Your comment has been published.'] = '';
$GLOBALS['__l10n']['Your comment has been submitted and will be reviewed for publication.'] = '';
$GLOBALS['__l10n']['Add a comment'] = '';
$GLOBALS['__l10n']['Name or nickname'] = '';
$GLOBALS['__l10n']['Email address'] = '';
$GLOBALS['__l10n']['Website'] = '';
$GLOBALS['__l10n']['optional'] = '';
$GLOBALS['__l10n']['Comment'] = '';
$GLOBALS['__l10n']['Comments can be formatted using a simple wiki syntax.'] = '';
$GLOBALS['__l10n']['HTML code is displayed as text and web addresses are automatically converted.'] = '';
$GLOBALS['__l10n']['Remember me on this blog'] = '';
$GLOBALS['__l10n']['preview'] = '';
$GLOBALS['__l10n']['send'] = '';
$GLOBALS['__l10n']['They posted on the same topic'] = '';
$GLOBALS['__l10n']['Trackback URL'] = '';
$GLOBALS['__l10n']['You must provide an author name'] = '';
$GLOBALS['__l10n']['You must provide a comment'] = '';
$GLOBALS['__l10n']['Email address is not valid'] = '';
$GLOBALS['__l10n']['Document not found'] = '';
$GLOBALS['__l10n']['The document you are looking for does not exist.'] = '';
$GLOBALS['__l10n']['Powered by %s'] = '';
$GLOBALS['__l10n']['Subscribe to'] = '';
$GLOBALS['__l10n']['What is an RSS feed?'] = '';
$GLOBALS['__l10n']['RSS feed is a free blog summary. It provides content (either posts or comments) or summaries of content, together with links to the full versions, and other metadata. The last published items may then be read by your favorite RSS <a href="http://en.wikipedia.org/wiki/Aggregator">aggregator</a>.'] = '';
$GLOBALS['__l10n']['Simply copy the following URL into your aggregator:'] = '';
$GLOBALS['__l10n']['Password needed'] = '';
$GLOBALS['__l10n']['You must give a password to access this area.'] = '';
$GLOBALS['__l10n']['Password:'] = '';
$GLOBALS['__l10n']['You must provide a valid email address.'] = '';
$GLOBALS['__l10n']['Read'] = '';
$GLOBALS['__l10n']['toDay'] = 'to';
$GLOBALS['__l10n']['FromDay'] = 'From';

==> dotclear-2.13.zip: dotclear/locales/en/public.lang.php <==
<?php
# -- BEGIN LICENSE BLOCK ---------------------------------------
#
# This file is part of Dotclear 2.
#
# Copyright (c) 2003-2013 Olivier Meunier & Association Dotclear
# Licensed under the GPL version 2.0 license.
# See LICENSE file or
# http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
#
# -- END LICENSE BLOCK -----------------------------------------#
#
#
#		  DOT NOT MODIFY THIS FILE !




$GLOBALS['__l10n']['To content'] = '';
$GLOBALS['__l10n']['To menu'] = '';
$GLOBALS['__l10n']['To search'] = '';
$GLOBALS['__l10n']['By'] = '';
$GLOBALS['__l10n']['by'] = '';
$GLOBALS['__l10n']['on'] = '';
$GLOBALS['__l10n']['On'] = '';
$GLOBALS['__l10n']['Continue reading'] = '';
$GLOBALS['__l10n']['no comments'] = '';
$GLOBALS['__l10n']['one comment'] = '';
$GLOBALS['__l10n']['%d comments'] = '';
$GLOBALS['__l10n']['no trackbacks'] = '';
$GLOBALS['__l10n']['one trackback'] = '';
$GLOBALS['__l10n']['%d trackbacks'] = '';
$GLOBALS['__l10n']['no attachments'] = '';
$GLOBALS['__l10n']['one attachment'] = '';
$GLOBALS['__l10n']['%d attachments'] = '';
$GLOBALS['__l10n']['previous entries'] = '';
$GLOBALS['__l10n']['page'] = '';
$GLOBALS['__l10n']['of'] = '';
$GLOBALS['__l10n']['next entries'] = '';
$GLOBALS['__l10n']['Search'] = '';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned no result.'] = '';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned <strong>%2$s</strong> result.'] = '';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned <strong>%2$s</strong> results.'] = '';
$GLOBALS['__l10n']['Home'] = '';
$GLOBALS['__l10n']['All keywords'] = '';
$GLOBALS['__l10n']['Best of me'] = '';
$GLOBALS['__l10n']['Languages'] = '';
$GLOBALS['__l10n']['Categories'] = '';
$GLOBALS['__l10n']['Subcategories'] = '';
$GLOBALS['__l10n']['Archives'] = '';
$GLOBALS['__l10n']['Links'] = '';
$GLOBALS['__l10n']['Subscribe'] = '';
$GLOBALS['__l10n']['Entries feed'] = '';
$GLOBALS['__l10n']['Comments feed'] = '';
$GLOBALS['__l10n']['This blog\'s comments Atom feed'] = '';
$GLOBALS['__l10n']['This category\'s entries Atom feed'] = '';
$GLOBALS['__l10n']['This category\'s comments Atom feed'] = '';
$GLOBALS['__l10n']['This post\'s comments feed'] = '';
$GLOBALS['__l10n']['This post\'s comments Atom feed'] = '';
$GLOBALS['__l10n']['Attachments'] = '';
$GLOBALS['__l10n']['Permalink'] = '';
$GLOBALS['__l10n']['Comments'] = '';
$GLOBALS['__l10n']['Your comment'] = '';
$GLOBALS['__l10n']['Your comment has been published.'] = '';
$GLOBALS['__l10n']['Your comment has been submitted and will be reviewed for publication.'] = '';
$GLOBALS['__l10n']['Add a comment'] = '';
$GLOBALS['__l10n']['Name or nickname'] = '';
$GLOBALS['__l10n']['Email address'] = '';
$GLOBALS['__l10n']['Website'] = '';
$GLOBALS['__l10n']['optional'] = '';
$GLOBALS['__l10n']['Comment'] = '';
$GLOBALS['__l10n']['Comments can be formatted using a simple wiki syntax.'] = '';
$GLOBALS['__l10n']['HTML code is displayed as text and web addresses are automatically converted.'] = '';
$GLOBALS['__l10n']['Remember me on this blog'] = '';
$GLOBALS['__l10n']['preview'] = '';
$GLOBALS['__l10n']['send'] = '';
$GLOBALS['__l10n']['They posted on the same topic'] = '';
$GLOBALS['__l10n']['Trackback URL'] = '';
$GLOBALS['__l10n']['You must provide an author name'] = '';
$GLOBALS['__l10n']['You must provide a comment'] = '';
$GLOBALS['__l10n']['Email address is not valid'] = '';
$GLOBALS['__l10n']['Document not found'] = '';
$GLOBALS['__l10n']['The document you are looking for does not exist.'] = '';
$GLOBALS['__l10n']['Powered by %s'] = '';
$GLOBALS['__l10n']['Subscribe to'] = '';
$GLOBALS['__l10n']['What is an RSS feed?'] = '';
$GLOBALS['__l10n']['RSS feed is a free blog summary. It provides content (either posts or comments) or summaries of content, together with links to the full versions, and other metadata. The last published items may then be read by your favorite RSS <a href="http://en.wikipedia.org/wiki/Aggregator">aggregator</a>.'] = '';
$GLOBALS['__l10n']['Simply copy the following URL into your aggregator:'] = '';
$GLOBALS['__l10n']['Password needed'] = '';
$GLOBALS['__l10n']['You must give a password to access this area.'] = '';
$GLOBALS['__l10n']['Password:'] = '';
$GLOBALS['__l10n']['You must provide a valid email address.'] = '';
$GLOBALS['__l10n']['Read'] = '';
$GLOBALS['__l10n']['in'] = '';
$GLOBALS['__l10n']['In'] = '';
$GLOBALS['__l10n']['Page top'] = '';
$GLOBALS['__l10n']['toDay'] = 'to';
$GLOBALS['__l10n']['FromDay'] = 'From';
$GLOBALS['__l10n']['By category'] = '';
$GLOBALS['__l10n']['By date'] = '';
$GLOBALS['__l10n']['By tag'] = '';
$GLOBALS['__l10n']['Blog menu'] = '';
$GLOBALS['__l10n']['Etra menu'] = '';
$GLOBALS['__l10n']['Blog info'] = '';
